# This script starts a simple Python webserver using Tornado and
# demonstrates usage of image parameters.

import base64
import json
import tornado.ioloop
import tornado.web
from tornado.web import HTTPError
from reportbro import Report

SERVER_PORT = 5000
IMAGE_REPORT_PATH = r"/report/image"


class ImageReportHandler(tornado.web.RequestHandler):
    def initialize(self):
        # load report template from local json file
        with open('10_images.json', 'r') as f:
            self.image_report_template = json.loads(f.read())

    def get(self):
        """"Handle GET request for image report.

        A previously created report template is used. In this template we showcase how to pass
        an image parameter in 4 different ways:
        base64-encoded, file object, url and local path
        """
        data = dict()
        # provide same image as parameter in different ways
        with open('rb_logo_dark.png', 'rb') as f:
            image_data = f.read()
            data['img1_base64'] = 'data:image/png;base64,' + base64.b64encode(image_data).decode('utf-8')
        data['img2_fileobj'] = open('rb_logo_dark.png', 'rb')
        data['img3_url'] = 'https://www.reportbro.com/static/images/rb_logo_dark.png'
        data['img4_localpath'] = 'file:rb_logo_dark.png'

        try:
            report = Report(self.image_report_template, data, allow_local_image=True, allow_external_image=True)
            if report.errors:
                raise HTTPError(400, reason='error generating report')
            report_file = report.generate_pdf()
            self.set_header('Content-Type', 'application/pdf')
            self.set_header('Content-Disposition', 'inline; filename="{filename}"'.format(filename='images.pdf'))
            self.write(report_file)
        except Exception as e:
            raise HTTPError(400, reason='failed to initialize report: ' + str(e))


def make_app():
    return tornado.web.Application([
        (IMAGE_REPORT_PATH, ImageReportHandler),
    ])


if __name__ == "__main__":
    app = make_app()
    app.listen(SERVER_PORT)
    tornado.ioloop.IOLoop.current().start()
